@@ -1,14 +1,13 @@
+"""Settings
+"""
+import configparser
 import importlib
 import os
 from os import getcwd
+from typing import Callable
 
 from .errors import ImproperConfigurationError
 
-try:
-    import configparser
-except ImportError:
-    import ConfigParser as configparser
-
 
 def _config():
     parser = configparser.ConfigParser()
@@ -22,7 +21,12 @@ def _config():
 config = _config()
 
 
-def current_commit_parser():
+def current_commit_parser() -> Callable:
+    """Current commit parser
+
+    :raises ImproperConfigurationError: if ImportError or AttributeError is raised
+    """
+
     try:
         parts = config.get('semantic_release', 'commit_parser').split('.')
         module = '.'.join(parts[:-1])
